VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "cTimer"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
'
'   Module          : cTimer
'   Description     : Hi-Performance Timer Class
'   Author          : C. Eswar Santhosh
'   Last Updated    : 08th February, 2000.
'   Notes           : If the System does not support a Hi-Resolution timer, uses the very approximate
'                     GetTickCount function. This class is used as a Stop Watch to measure elapsed time
'                     between StartTimer() and EndTimer() Calls.
'
'   Copyright Info  :
'
'   This Class module is provided AS-IS. This Class module can be used as a part of a compiled
'   executable whether freeware or not. This Class module may not be posted to any web site
'   or BBS or any redistributable media like CD-ROM without the consent of the author.
'
'   e-mail   : eswar_santhosh@yahoo.com
'
'   Revision History :
'                       1.0.0 Primera revisi�n para XMR
'
'
'-------------------------------------------------------------------------------------------------------------
Option Explicit
'
' API Declarations
'
Private Declare Function QueryPerformanceCounter _
                Lib "kernel32" (lpPerformanceCount As Currency) As Long
Private Declare Function QueryPerformanceFrequency _
                Lib "kernel32" (lpFrequency As Currency) As Long
Private Declare Function GetTickCount _
                Lib "kernel32" () As Long
'
' Local Variables
'
Dim timStart As Currency    ' The Starting Counter of the Timer
Dim timElapsed As Double    ' No. of Elapsed Milliseconds
Dim nFrequency As Currency  ' Frequency of the Hi-Resolution timer if it is avilable, else zero
Dim bRunning As Boolean     ' Is the Timer running ?

Public Sub EndTimer()
Attribute EndTimer.VB_Description = "Ends the Timer"
        '
        ' Ends the Counter
        '

100     timElapsed = GetElapsedTime     ' Store this Value
102     bRunning = False

End Sub

Public Sub StartTimer()
Attribute StartTimer.VB_Description = "Starts the Timer"
        '
        ' Starts the Counter
        '

100     timElapsed = 0      ' Reset Counter
102     bRunning = True

104     If nFrequency <> 0 Then
106         QueryPerformanceCounter timStart
        Else
108         timStart = GetTickCount
        End If

End Sub

Private Function GetElapsedTime() As Double
        '
        ' Calculates the Elapsed Time
        '

        Dim timEnd As Currency

100     If nFrequency <> 0 Then
102         QueryPerformanceCounter timEnd
104         GetElapsedTime = ((timEnd - timStart) / nFrequency) * 1000
        Else
106         timEnd = GetTickCount
108         GetElapsedTime = timEnd - timStart
        End If

End Function

Private Sub Class_Initialize()
        '
        ' Check if Hi-resolution timer is available

        Dim APIRetVal As Long
100     APIRetVal = QueryPerformanceFrequency(nFrequency)

102     If APIRetVal = 0 Then
104         nFrequency = 0          ' Zero indicates that the ordinary GetTickCount function must be used
        End If

End Sub

Public Property Get Elapsed() As Double
Attribute Elapsed.VB_Description = "Returns Elapsed Time in MilliSeconds. If the Timer is running, returns Zero."
        '
        ' Returns Elapsed time
        '
100     If bRunning Then
102         Elapsed = GetElapsedTime    ' Return Intermediate Time
        Else
104         Elapsed = timElapsed        ' Return the Last counter's timing
        End If

End Property

Public Property Get Frecuencia() As Currency
        '
        ' Regresa la frecuencia del timer
        '
100     Frecuencia = nFrequency

End Property

Public Property Get IsHiTimer() As Boolean
Attribute IsHiTimer.VB_Description = "Returns True if the System supports a Hi-Resolution timer"
        '
        ' Returns True if a Hi-Performance timer is used
        '
100     IsHiTimer = (nFrequency <> 0)
End Property

